==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_ts() {
            return 1;
        }
        get_ul() {
            return new ForceIndexIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return ForceIndexIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(ForceIndexIndicator.u7));
        }
        set u6(a) {
            this.h(ForceIndexIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    ForceIndexIndicator.$t = /*@__PURE__*/ markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.u7 = /*@__PURE__*/ StrategyBasedIndicator.u3(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();

==> igniteui-react-charts-18.2.0.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        get_tw() {
            return 1;
        }
        constructor() {
            super();
        }
        get_up() {
            return new ForceIndexIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return ForceIndexIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get va() {
            return typeGetValue(this.c(ForceIndexIndicator.vb));
        }
        set va(a) {
            this.h(ForceIndexIndicator.vb, a);
        }
        uv() {
            return this.va;
        }
        u4(a) {
            this.va = a;
        }
    }
    ForceIndexIndicator.$t = /*@__PURE__*/ markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.vb = /*@__PURE__*/ StrategyBasedIndicator.u7(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();
